==> sk-dialog-jquery-0.2.6.tgz: package/src/jquery-sk-dialog.js <==

import { SkDialogImpl }  from '../../sk-dialog/src/impl/sk-dialog-impl.js';

export class JquerySkDialog extends SkDialogImpl {

    get prefix() {
        return 'jquery';
    }

    get suffix() {
        return 'dialog';
    }

    get tplFooterPath() {
        if (! this._tplFooterPath) {
            this._tplFooterPath = (this.comp.configEl && this.comp.configEl.hasAttribute('tpl-path'))
                ? `/${this.comp.configEl.getAttribute('tpl-path')}/${this.prefix}-sk-${this.suffix}-footer.tpl.html`
                :`/node_modules/sk-${this.comp.cnSuffix}-${this.prefix}/src/${this.prefix}-sk-${this.suffix}-footer.tpl.html`;
        }
        return this._tplFooterPath;
    }

    get dialog() {
        if (! this._dialog) {
            this._dialog = this.comp.el.querySelector(this.comp.dialogTn);
        }
        return this._dialog;
    }

    set dialog(dialog) {
        this._dialog = dialog;
    }

    get body() {
        return this.dialog.querySelector('.ui-dialog-content');
    }

    get closeBtn() {
        return this.dialog.querySelector('.ui-dialog-titlebar-close');
    }

    get footerEl() {
        return this.dialog.querySelector('.ui-dialog-footer');
    }

    get headerEl() {
        return this.dialog.querySelector('.ui-dialog-titlebar');
    }

    get titleEl() {
        return this.dialog.querySelector('.ui-dialog-title');
    }

    get btnCancelEl() {
        return this.dialog.querySelector('.btn-cancel');
    }

    get btnConfirmEl() {
        return this.dialog.querySelector('.btn-confirm');
    }

    restoreState(state) {
        this.body.innerHTML = '';
        this.body.insertAdjacentHTML('beforeend', state.contentsState);
    }

    beforeRendered() {
        super.beforeRendered();
        this.saveState();
    }

    afterRendered() {
        //super.afterRendered();
        this.restoreState({ contentsState: this.contentsState || this.comp.contentsState });
        if (this.dialog) {
            this.polyfillNativeDialog(this.dialog);
        }
        this.bindEvents();
        this.close();
        this.renderTitle();
        if (this.comp.type === 'confirm') {
            this.renderFooter();
        }
        this.bindActions(this.dialog);
        this.mountStyles();
    }

    bindEvents() {
        super.bindEvents();
        this.closeBtn.onclick = function(event) {
            this.close(event);
        }.bind(this);
    }

    unbindEvents() {
        super.unbindEvents();
        this.closeBtn.removeEventListener('click', this.close);
    }

}

==> sk-dialog-jquery-0.2.10.tgz: package/src/jquery-sk-dialog.js <==

import { SkDialogImpl }  from '../../sk-dialog/src/impl/sk-dialog-impl.js';

export class JquerySkDialog extends SkDialogImpl {

    get prefix() {
        return 'jquery';
    }

    get suffix() {
        return 'dialog';
    }

    get tplFooterPath() {
        if (! this._tplFooterPath) {
            this._tplFooterPath = (this.comp.configEl && this.comp.configEl.hasAttribute('tpl-path'))
                ? `${this.comp.configEl.getAttribute('tpl-path')}/${this.prefix}-sk-${this.suffix}-footer.tpl.html`
                :`/node_modules/sk-${this.comp.cnSuffix}-${this.prefix}/src/${this.prefix}-sk-${this.suffix}-footer.tpl.html`;
        }
        return this._tplFooterPath;
    }

    get dialog() {
        if (! this._dialog) {
            this._dialog = this.comp.el.querySelector(this.comp.dialogTn);
        }
        return this._dialog;
    }

    set dialog(dialog) {
        this._dialog = dialog;
    }

    get body() {
        return this.dialog.querySelector('.ui-dialog-content');
    }

    get closeBtn() {
        return this.dialog.querySelector('.ui-dialog-titlebar-close');
    }

    get footerEl() {
        return this.dialog.querySelector('.ui-dialog-footer');
    }

    get headerEl() {
        return this.dialog.querySelector('.ui-dialog-titlebar');
    }

    get titleEl() {
        return this.dialog.querySelector('.ui-dialog-title');
    }

    get btnCancelEl() {
        return this.dialog.querySelector('.btn-cancel');
    }

    get btnConfirmEl() {
        return this.dialog.querySelector('.btn-confirm');
    }

    restoreState(state) {
        this.body.innerHTML = '';
        this.body.insertAdjacentHTML('beforeend', state.contentsState);
    }

    beforeRendered() {
        super.beforeRendered();
        this.saveState();
    }

    afterRendered() {
        //super.afterRendered();
        this.restoreState({ contentsState: this.contentsState || this.comp.contentsState });
        if (this.dialog) {
            this.polyfillNativeDialog(this.dialog);
        }
        this.bindEvents();
        this.close();
        this.renderTitle();
        if (this.comp.type === 'confirm') {
            this.renderFooter();
        }
        this.bindActions(this.dialog);
        this.mountStyles();
    }

    bindEvents() {
        super.bindEvents();
        this.closeBtn.onclick = function(event) {
            this.close(event);
        }.bind(this);
    }

    unbindEvents() {
        super.unbindEvents();
        this.closeBtn.removeEventListener('click', this.close);
    }

}
